package
Version:
v1.3.7
Opens a new window with list of versions in this module.
Published: May 19, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
ServerURL string `json:"server_url"`
AgentToken string `json:"agent_token"`
AgentID int64 `json:"agent_id"`
ReverbURL string `json:"reverb_url"`
ReverbAppKey string `json:"reverb_app_key"`
AuthEndpoint string `json:"auth_endpoint"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.